@@ -1,55 +1,167 @@
+( cd opt/kde/share/doc/HTML/pt/ark ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/ark ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kdf ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kdf ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kdm ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kdm ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kig ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kig ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/juk ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/juk ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kpf ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kpf ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/amor ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/amor ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kate ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kate ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kdat ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kdat ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kdvi ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kdvi ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kget ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kget ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kgpg ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kgpg ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kmag ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kmag ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kmid ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kmid ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kmix ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kmix ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kodo ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kodo ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kolf ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kolf ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kpat ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kpat ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kpdf ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kpdf ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kppp ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kppp ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/krdc ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/krdc ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/krfb ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/krfb ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kscd ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kscd ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/ksim ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/ksim ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/lisa ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/lisa ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kxkb ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kxkb ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kalzium ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kalzium ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/katomic ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/katomic ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/ksysguard ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/ksysguard ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kbounce ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kbounce ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kbattleship ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kbattleship ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kaboodle ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kaboodle ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/knewsticker ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/knewsticker ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/khangman ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/khangman ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kfloppy ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kfloppy ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/cervisia ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/cervisia ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/khexedit ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/khexedit ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kpercentage ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kpercentage ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kcalc ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kcalc ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kdesu ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kdesu ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kcron ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kcron ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kdict ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kdict ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kedit ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kedit ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kfind ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kfind ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kiten ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kiten ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kjots ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kjots ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kmoon ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kmoon ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kooka ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kooka ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/ksame ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/ksame ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/ksirc ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/ksirc ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/ksysv ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/ksysv ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/ktron ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/ktron ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kuser ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kuser ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kview ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kview ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kwin4 ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kwin4 ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/lskat ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/lskat ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kgoldrunner ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kgoldrunner ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kcoloredit ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kcoloredit ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/klipper ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/klipper ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kvoctrain ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kvoctrain ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kmousetool ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kmousetool ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/ksnapshot ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/ksnapshot ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kompare ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kompare ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/konsole ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/konsole ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kcachegrind ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kcachegrind ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kpackage ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kpackage ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/khelpcenter ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/khelpcenter ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kshisen ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kshisen ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/ksirtet ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/ksirtet ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/konquest ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/konquest ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kspaceduel ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kspaceduel ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kverbos ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kverbos ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kwallet ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kwallet ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kweather ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kweather ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kwuftpd ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kwuftpd ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kxsldbg ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kxsldbg ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kwifimanager ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kwifimanager ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kbugbuster ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kbugbuster ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kmenuedit ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kmenuedit ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kioslave ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kioslave ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/flashkard ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/flashkard ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kbackgammon ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kbackgammon ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kaddressbook ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kaddressbook ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kxconfig ; rm -rf common )
@@ -90,6 +202,8 @@
 ( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/grad.png grad.png )
 ( cd opt/kde/share/doc/HTML/pt/common ; rm -rf kde-web.css )
 ( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/kde-web.css kde-web.css )
+( cd opt/kde/share/doc/HTML/pt/common ; rm -rf kde_logo_bg.png )
+( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/kde_logo_bg.png kde_logo_bg.png )
 ( cd opt/kde/share/doc/HTML/pt/common ; rm -rf lgpl-license.html )
 ( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/lgpl-license.html lgpl-license.html )
 ( cd opt/kde/share/doc/HTML/pt/common ; rm -rf doxygen.css )
@@ -104,12 +218,16 @@
 ( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/footer.html footer.html )
 ( cd opt/kde/share/doc/HTML/pt/common ; rm -rf kde-common.css )
 ( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/kde-common.css kde-common.css )
+( cd opt/kde/share/doc/HTML/pt/common ; rm -rf appheader.html )
+( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/appheader.html appheader.html )
 ( cd opt/kde/share/doc/HTML/pt/common ; rm -rf doctop1.png )
 ( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/doctop1.png doctop1.png )
 ( cd opt/kde/share/doc/HTML/pt/common ; rm -rf doctop2.png )
 ( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/doctop2.png doctop2.png )
 ( cd opt/kde/share/doc/HTML/pt/common ; rm -rf shadow.png )
 ( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/shadow.png shadow.png )
+( cd opt/kde/share/doc/HTML/pt/common ; rm -rf kde_logo.png )
+( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/kde_logo.png kde_logo.png )
 ( cd opt/kde/share/doc/HTML/pt/common ; rm -rf docheadergears.png )
 ( cd opt/kde/share/doc/HTML/pt/common ; ln -sf ../../en/common/docheadergears.png docheadergears.png )
 ( cd opt/kde/share/doc/HTML/pt/common ; rm -rf fdl-license.html )
@@ -184,10 +302,14 @@
 ( cd opt/kde/share/doc/HTML/pt/kcontrol/proxy ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kcontrol/kmixcfg ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kcontrol/kmixcfg ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kcontrol/desktopbehavior ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kcontrol/desktopbehavior ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kcontrol/lanbrowser ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kcontrol/lanbrowser ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kcontrol/passwords ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kcontrol/passwords ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kcontrol/panelappearance ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kcontrol/panelappearance ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kcontrol/ebrowsing ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kcontrol/ebrowsing ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kcontrol/background ; rm -rf common )
@@ -246,34 +368,100 @@
 ( cd opt/kde/share/doc/HTML/pt/kcontrol/kthememgr ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kcontrol/kcmfontinst ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kcontrol/kcmfontinst ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/artsbuilder ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/artsbuilder ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kicker-applets ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kicker-applets ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/konq-plugins ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/konq-plugins ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kbabel ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kbabel ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kamera ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kamera ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kdeprint ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kdeprint ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kasteroids ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kasteroids ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kbruch ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kbruch ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/keduca ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/keduca ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kgamma ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kgamma ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kmessedwords ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kmessedwords ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kicker ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kicker ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/klines ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/klines ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kmines ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kmines ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kmouth ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kmouth ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kmplot ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kmplot ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kpager ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kpager ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kpaint ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kpaint ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kopete ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kopete ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kpoker ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kpoker ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kruler ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kruler ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/ktalkd ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/ktalkd ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/ksnake ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/ksnake ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kspell ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kspell ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kstars ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kstars ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/ktimer ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/ktimer ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/ktouch ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/ktouch ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kwrite ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kwrite ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kreversi ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kreversi ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/noatun ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/noatun ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/ksplashml ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/ksplashml ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kdebugdialog ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kdebugdialog ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kblackbox ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kblackbox ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kcharselect ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kcharselect ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
-( cd opt/kde/share/doc/HTML/pt/kaphorism ; rm -rf common )
-( cd opt/kde/share/doc/HTML/pt/kaphorism ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/quanta ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/quanta ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kuickshow ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kuickshow ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kiconedit ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kiconedit ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/klettres ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/klettres ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kfouleggs ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kfouleggs ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kghostview ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kghostview ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/klickety ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/klickety ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kpovmodeler ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kpovmodeler ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kjumpingcube ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kjumpingcube ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kenolaba ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kenolaba ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kworldclock ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kworldclock ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/KRegExpEditor ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/KRegExpEditor ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/ksokoban ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/ksokoban ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kteatime ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kteatime ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kmathtool ; rm -rf common )
@@ -316,3 +504,9 @@
 ( cd opt/kde/share/doc/HTML/pt/kinfocenter/protocols ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kate-plugins ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kate-plugins ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/umbrello ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/umbrello ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/konqueror ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/konqueror ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/atlantik ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/atlantik ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
